pub struct AstGrepToolSettings {
pub absolute_paths: bool,
}Fields
absolute_paths: boolTrait Implementations
Sourceimpl Clone for AstGrepToolSettings
impl Clone for AstGrepToolSettings
Sourcefn clone(&self) -> AstGrepToolSettings
fn clone(&self) -> AstGrepToolSettings
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AstGrepToolSettings
impl Debug for AstGrepToolSettings
Sourceimpl Default for AstGrepToolSettings
impl Default for AstGrepToolSettings
Sourceimpl<'de> Deserialize<'de> for AstGrepToolSettings
impl<'de> Deserialize<'de> for AstGrepToolSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AstGrepToolSettings
Sourceimpl JsonSchema for AstGrepToolSettings
impl JsonSchema for AstGrepToolSettings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AstGrepToolSettings
impl PartialEq for AstGrepToolSettings
Sourceimpl Serialize for AstGrepToolSettings
impl Serialize for AstGrepToolSettings
impl StructuralPartialEq for AstGrepToolSettings