pub struct BashProtectionSettings {
pub enabled: bool,
pub protection_level: BashProtectionLevel,
pub failure_policy: BashProtectionFailurePolicy,
}Fields
enabled: boolprotection_level: BashProtectionLevelfailure_policy: BashProtectionFailurePolicyTrait Implementations
Sourceimpl Clone for BashProtectionSettings
impl Clone for BashProtectionSettings
Sourceimpl Debug for BashProtectionSettings
impl Debug for BashProtectionSettings
Sourceimpl Default for BashProtectionSettings
impl Default for BashProtectionSettings
Sourceimpl<'de> Deserialize<'de> for BashProtectionSettings
impl<'de> Deserialize<'de> for BashProtectionSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BashProtectionSettings
impl JsonSchema for BashProtectionSettings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BashProtectionSettings
impl PartialEq for BashProtectionSettings
Sourceimpl Serialize for BashProtectionSettings
impl Serialize for BashProtectionSettings
impl StructuralPartialEq for BashProtectionSettings