pub struct CodeModeToolSettings {
pub enabled: bool,
pub compact_direct_tools: bool,
pub nudges_enabled: bool,
pub disabled: Vec<String>,
pub limits: CodeModeLimits,
}Fields
enabled: boolcompact_direct_tools: boolnudges_enabled: booldisabled: Vec<String>Tools unavailable inside Code Mode, independent of direct-tool availability.
limits: CodeModeLimitsTrait Implementations
Sourceimpl Clone for CodeModeToolSettings
impl Clone for CodeModeToolSettings
Sourceimpl Debug for CodeModeToolSettings
impl Debug for CodeModeToolSettings
Sourceimpl Default for CodeModeToolSettings
impl Default for CodeModeToolSettings
Sourceimpl<'de> Deserialize<'de> for CodeModeToolSettingswhere
CodeModeToolSettings: Default,
impl<'de> Deserialize<'de> for CodeModeToolSettingswhere
CodeModeToolSettings: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CodeModeToolSettings
Sourceimpl JsonSchema for CodeModeToolSettings
impl JsonSchema for CodeModeToolSettings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CodeModeToolSettings
impl PartialEq for CodeModeToolSettings
Sourceimpl Serialize for CodeModeToolSettings
impl Serialize for CodeModeToolSettings
impl StructuralPartialEq for CodeModeToolSettings