pub struct CompactionTimingSettings {
pub enabled: bool,
pub soft_threshold_percent: u8,
pub threshold: f64,
}Fields
enabled: boolsoft_threshold_percent: u8threshold: f64Trait Implementations
Sourceimpl Clone for CompactionTimingSettings
impl Clone for CompactionTimingSettings
Sourceimpl Debug for CompactionTimingSettings
impl Debug for CompactionTimingSettings
Sourceimpl Default for CompactionTimingSettings
impl Default for CompactionTimingSettings
Sourceimpl<'de> Deserialize<'de> for CompactionTimingSettings
impl<'de> Deserialize<'de> for CompactionTimingSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CompactionTimingSettings
impl JsonSchema for CompactionTimingSettings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CompactionTimingSettings
impl PartialEq for CompactionTimingSettings
Sourceimpl Serialize for CompactionTimingSettings
impl Serialize for CompactionTimingSettings
impl StructuralPartialEq for CompactionTimingSettings