pub struct CompactionVerificationSettings {
pub enabled: bool,
pub enforcement_enabled: bool,
pub threshold: f64,
pub max_state_bytes: usize,
pub failure_policy: CompactionVerificationFailurePolicy,
}Fields
enabled: boolenforcement_enabled: boolthreshold: f64max_state_bytes: usizefailure_policy: CompactionVerificationFailurePolicyTrait Implementations
Sourceimpl Clone for CompactionVerificationSettings
impl Clone for CompactionVerificationSettings
Sourcefn clone(&self) -> CompactionVerificationSettings
fn clone(&self) -> CompactionVerificationSettings
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for CompactionVerificationSettings
impl<'de> Deserialize<'de> for CompactionVerificationSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CompactionVerificationSettings
impl JsonSchema for CompactionVerificationSettings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for CompactionVerificationSettings