pub struct CompletionVerificationSettings {
pub enabled: bool,
pub enforcement_enabled: bool,
pub threshold: f64,
pub max_state_bytes: usize,
pub max_continuations: u8,
pub failure_policy: CompletionVerificationFailurePolicy,
}Fields
enabled: boolenforcement_enabled: boolthreshold: f64max_state_bytes: usizemax_continuations: u8failure_policy: CompletionVerificationFailurePolicyTrait Implementations
Sourceimpl<'de> Deserialize<'de> for CompletionVerificationSettings
impl<'de> Deserialize<'de> for CompletionVerificationSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CompletionVerificationSettings
impl JsonSchema for CompletionVerificationSettings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for CompletionVerificationSettings