pub struct CustomProviderConfig {
pub label: String,
pub base_url: String,
pub api_key_env_var: Option<String>,
pub models_dev_provider: Option<String>,
pub use_responses_endpoint: bool,
pub supports_text_verbosity: bool,
pub reasoning_protocol: CustomReasoningProtocol,
pub extra_models: Vec<String>,
}Fields
label: Stringbase_url: Stringapi_key_env_var: Option<String>models_dev_provider: Option<String>use_responses_endpoint: boolsupports_text_verbosity: boolreasoning_protocol: CustomReasoningProtocolextra_models: Vec<String>Trait Implementations
Sourceimpl Clone for CustomProviderConfig
impl Clone for CustomProviderConfig
Sourcefn clone(&self) -> CustomProviderConfig
fn clone(&self) -> CustomProviderConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CustomProviderConfig
impl Debug for CustomProviderConfig
Sourceimpl<'de> Deserialize<'de> for CustomProviderConfig
impl<'de> Deserialize<'de> for CustomProviderConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CustomProviderConfig
Sourceimpl JsonSchema for CustomProviderConfig
impl JsonSchema for CustomProviderConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CustomProviderConfig
impl PartialEq for CustomProviderConfig
Sourceimpl Serialize for CustomProviderConfig
impl Serialize for CustomProviderConfig
impl StructuralPartialEq for CustomProviderConfig