pub struct FastSettings {
pub enabled: bool,
}Fields
enabled: boolTrait Implementations
Sourceimpl Clone for FastSettings
impl Clone for FastSettings
Sourcefn clone(&self) -> FastSettings
fn clone(&self) -> FastSettings
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FastSettings
impl Debug for FastSettings
Sourceimpl Default for FastSettings
impl Default for FastSettings
Sourcefn default() -> FastSettings
fn default() -> FastSettings
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for FastSettings
impl<'de> Deserialize<'de> for FastSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for FastSettings
Sourceimpl JsonSchema for FastSettings
impl JsonSchema for FastSettings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FastSettings
impl PartialEq for FastSettings
Sourceimpl Serialize for FastSettings
impl Serialize for FastSettings
impl StructuralPartialEq for FastSettings