pub struct HookDefinition {
pub label: Option<String>,
pub command: String,
pub payload: Option<HookPayloadMode>,
pub failure_policy: Option<HookFailurePolicy>,
pub timeout_seconds: Option<u64>,
pub stdout_max_bytes: Option<usize>,
pub stderr_max_bytes: Option<usize>,
pub provider_context_injection: Option<bool>,
pub provider_context_max_bytes: Option<usize>,
pub include_tools: Vec<String>,
pub exclude_tools: Vec<String>,
}Fields
label: Option<String>command: Stringpayload: Option<HookPayloadMode>failure_policy: Option<HookFailurePolicy>timeout_seconds: Option<u64>stdout_max_bytes: Option<usize>stderr_max_bytes: Option<usize>provider_context_injection: Option<bool>provider_context_max_bytes: Option<usize>include_tools: Vec<String>exclude_tools: Vec<String>Trait Implementations
Sourceimpl Clone for HookDefinition
impl Clone for HookDefinition
Sourcefn clone(&self) -> HookDefinition
fn clone(&self) -> HookDefinition
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HookDefinition
impl Debug for HookDefinition
Sourceimpl Default for HookDefinition
impl Default for HookDefinition
Sourcefn default() -> HookDefinition
fn default() -> HookDefinition
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for HookDefinition
impl<'de> Deserialize<'de> for HookDefinition
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for HookDefinition
Sourceimpl JsonSchema for HookDefinition
impl JsonSchema for HookDefinition
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for HookDefinition
impl PartialEq for HookDefinition
Sourceimpl Serialize for HookDefinition
impl Serialize for HookDefinition
impl StructuralPartialEq for HookDefinition