pub struct HumanizeProtectionSettings {
pub enabled: bool,
pub content_threshold: f64,
pub humanized_threshold: f64,
pub failure_policy: HumanizeProtectionFailurePolicy,
}Fields
enabled: boolcontent_threshold: f64humanized_threshold: f64failure_policy: HumanizeProtectionFailurePolicyTrait Implementations
Sourceimpl Clone for HumanizeProtectionSettings
impl Clone for HumanizeProtectionSettings
Sourceimpl Debug for HumanizeProtectionSettings
impl Debug for HumanizeProtectionSettings
Sourceimpl Default for HumanizeProtectionSettings
impl Default for HumanizeProtectionSettings
Sourceimpl<'de> Deserialize<'de> for HumanizeProtectionSettings
impl<'de> Deserialize<'de> for HumanizeProtectionSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HumanizeProtectionSettings
impl JsonSchema for HumanizeProtectionSettings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for HumanizeProtectionSettings