pub struct InjectedContentSettings {
pub show_in_transcript: bool,
pub show_in_activity_tree: bool,
pub style: InjectedContentStyle,
}Fields
show_in_transcript: boolshow_in_activity_tree: boolstyle: InjectedContentStyleTrait Implementations
Sourceimpl Clone for InjectedContentSettings
impl Clone for InjectedContentSettings
Sourcefn clone(&self) -> InjectedContentSettings
fn clone(&self) -> InjectedContentSettings
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InjectedContentSettings
impl Debug for InjectedContentSettings
Sourceimpl Default for InjectedContentSettings
impl Default for InjectedContentSettings
Sourcefn default() -> InjectedContentSettings
fn default() -> InjectedContentSettings
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for InjectedContentSettings
impl<'de> Deserialize<'de> for InjectedContentSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for InjectedContentSettings
Sourceimpl JsonSchema for InjectedContentSettings
impl JsonSchema for InjectedContentSettings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for InjectedContentSettings
impl PartialEq for InjectedContentSettings
Sourceimpl Serialize for InjectedContentSettings
impl Serialize for InjectedContentSettings
impl StructuralPartialEq for InjectedContentSettings