pub struct JevSettings {
pub enabled: bool,
pub show_debug_messages: bool,
pub bash_protection: BashProtectionSettings,
pub bash_file_tracking: BashFileTrackingSettings,
pub humanize_protection: HumanizeProtectionSettings,
pub prompt_injection_protection: PromptInjectionProtectionSettings,
pub completion_verification: CompletionVerificationSettings,
pub skill_suggestion: SkillSuggestionSettings,
pub compaction_timing: CompactionTimingSettings,
}Fields
enabled: boolshow_debug_messages: boolbash_protection: BashProtectionSettingsbash_file_tracking: BashFileTrackingSettingshumanize_protection: HumanizeProtectionSettingsprompt_injection_protection: PromptInjectionProtectionSettingscompletion_verification: CompletionVerificationSettingsskill_suggestion: SkillSuggestionSettingscompaction_timing: CompactionTimingSettingsTrait Implementations
Sourceimpl Clone for JevSettings
impl Clone for JevSettings
Sourceimpl Debug for JevSettings
impl Debug for JevSettings
Sourceimpl Default for JevSettings
impl Default for JevSettings
Sourceimpl<'de> Deserialize<'de> for JevSettings
impl<'de> Deserialize<'de> for JevSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for JevSettings
impl JsonSchema for JevSettings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for JevSettings
impl PartialEq for JevSettings
Sourceimpl Serialize for JevSettings
impl Serialize for JevSettings
impl StructuralPartialEq for JevSettings