pub struct ListFilesToolSettings {
pub absolute_paths: bool,
}Fields
absolute_paths: boolTrait Implementations
Sourceimpl Clone for ListFilesToolSettings
impl Clone for ListFilesToolSettings
Sourcefn clone(&self) -> ListFilesToolSettings
fn clone(&self) -> ListFilesToolSettings
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListFilesToolSettings
impl Debug for ListFilesToolSettings
Sourceimpl Default for ListFilesToolSettings
impl Default for ListFilesToolSettings
Sourceimpl<'de> Deserialize<'de> for ListFilesToolSettings
impl<'de> Deserialize<'de> for ListFilesToolSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ListFilesToolSettings
Sourceimpl JsonSchema for ListFilesToolSettings
impl JsonSchema for ListFilesToolSettings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ListFilesToolSettings
impl PartialEq for ListFilesToolSettings
Sourceimpl Serialize for ListFilesToolSettings
impl Serialize for ListFilesToolSettings
impl StructuralPartialEq for ListFilesToolSettings