pub struct McpHttpServerConfig {
pub url: String,
pub headers: BTreeMap<String, String>,
pub oauth: Option<McpOAuthConfig>,
pub enabled: bool,
pub timeout: Option<u64>,
}Fields
url: Stringheaders: BTreeMap<String, String>oauth: Option<McpOAuthConfig>enabled: booltimeout: Option<u64>Trait Implementations
Sourceimpl Clone for McpHttpServerConfig
impl Clone for McpHttpServerConfig
Sourcefn clone(&self) -> McpHttpServerConfig
fn clone(&self) -> McpHttpServerConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpHttpServerConfig
impl Debug for McpHttpServerConfig
Sourceimpl<'de> Deserialize<'de> for McpHttpServerConfig
impl<'de> Deserialize<'de> for McpHttpServerConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for McpHttpServerConfig
Sourceimpl JsonSchema for McpHttpServerConfig
impl JsonSchema for McpHttpServerConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for McpHttpServerConfig
impl PartialEq for McpHttpServerConfig
Sourceimpl Serialize for McpHttpServerConfig
impl Serialize for McpHttpServerConfig
impl StructuralPartialEq for McpHttpServerConfig