pub struct McpOAuthConfig {
pub client_id: Option<String>,
pub scopes: Vec<String>,
pub authorization_server: Option<String>,
}Fields
client_id: Option<String>scopes: Vec<String>Trait Implementations
Sourceimpl Clone for McpOAuthConfig
impl Clone for McpOAuthConfig
Sourcefn clone(&self) -> McpOAuthConfig
fn clone(&self) -> McpOAuthConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpOAuthConfig
impl Debug for McpOAuthConfig
Sourceimpl Default for McpOAuthConfig
impl Default for McpOAuthConfig
Sourcefn default() -> McpOAuthConfig
fn default() -> McpOAuthConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for McpOAuthConfig
impl<'de> Deserialize<'de> for McpOAuthConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for McpOAuthConfig
Sourceimpl JsonSchema for McpOAuthConfig
impl JsonSchema for McpOAuthConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for McpOAuthConfig
impl PartialEq for McpOAuthConfig
Sourceimpl Serialize for McpOAuthConfig
impl Serialize for McpOAuthConfig
impl StructuralPartialEq for McpOAuthConfig