pub struct McpStdioServerConfig {
pub command: String,
pub args: Vec<String>,
pub env: BTreeMap<String, String>,
pub enabled: bool,
pub timeout: Option<u64>,
}Fields
command: Stringargs: Vec<String>env: BTreeMap<String, String>enabled: booltimeout: Option<u64>Trait Implementations
Sourceimpl Clone for McpStdioServerConfig
impl Clone for McpStdioServerConfig
Sourcefn clone(&self) -> McpStdioServerConfig
fn clone(&self) -> McpStdioServerConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpStdioServerConfig
impl Debug for McpStdioServerConfig
Sourceimpl<'de> Deserialize<'de> for McpStdioServerConfig
impl<'de> Deserialize<'de> for McpStdioServerConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for McpStdioServerConfig
Sourceimpl JsonSchema for McpStdioServerConfig
impl JsonSchema for McpStdioServerConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for McpStdioServerConfig
impl PartialEq for McpStdioServerConfig
Sourceimpl Serialize for McpStdioServerConfig
impl Serialize for McpStdioServerConfig
impl StructuralPartialEq for McpStdioServerConfig