pub struct Settings {Show 23 fields
pub selected_model: SelectedModelSettings,
pub openai_codex: OpenAiCodexSettings,
pub openai_responses: OpenAiResponsesSettings,
pub no_color: Option<bool>,
pub anthropic_cache_ttl: Option<AnthropicCacheTtl>,
pub file_autocomplete_respects_gitignore: bool,
pub context: Option<ContextBudget>,
pub session_titles: SessionTitleSettings,
pub compaction: CompactionSettings,
pub tools: ToolSettings,
pub subagents: SubagentsSettings,
pub models: ModelsSettings,
pub hooks: HookSettings,
pub instructions: InstructionsSettings,
pub skills: SkillsSettings,
pub custom_providers: BTreeMap<String, CustomProviderConfig>,
pub mcp_servers: McpServersSettings,
pub lsp: LspSettings,
pub integrations: IntegrationsSettings,
pub tui: TuiSettings,
pub provider_stream: ProviderStreamSettings,
pub ttsr: TtsrSettings,
pub selected_primary_agent: Option<String>,
}Fields
selected_model: SelectedModelSettingsopenai_codex: OpenAiCodexSettingsopenai_responses: OpenAiResponsesSettingsno_color: Option<bool>anthropic_cache_ttl: Option<AnthropicCacheTtl>file_autocomplete_respects_gitignore: boolcontext: Option<ContextBudget>session_titles: SessionTitleSettingscompaction: CompactionSettingstools: ToolSettingssubagents: SubagentsSettingsmodels: ModelsSettingshooks: HookSettingsinstructions: InstructionsSettingsskills: SkillsSettingscustom_providers: BTreeMap<String, CustomProviderConfig>mcp_servers: McpServersSettingslsp: LspSettingsintegrations: IntegrationsSettingstui: TuiSettingsprovider_stream: ProviderStreamSettingsttsr: TtsrSettingsselected_primary_agent: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Settings
impl<'de> Deserialize<'de> for Settings
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Settings
Sourceimpl JsonSchema for Settings
impl JsonSchema for Settings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for Settings