pub struct SkillSuggestionSettings {
pub enabled: bool,
pub gate_threshold: f64,
pub fit_threshold: f64,
}Fields
enabled: boolgate_threshold: f64fit_threshold: f64Trait Implementations
Sourceimpl Clone for SkillSuggestionSettings
impl Clone for SkillSuggestionSettings
Sourceimpl Debug for SkillSuggestionSettings
impl Debug for SkillSuggestionSettings
Sourceimpl Default for SkillSuggestionSettings
impl Default for SkillSuggestionSettings
Sourceimpl<'de> Deserialize<'de> for SkillSuggestionSettings
impl<'de> Deserialize<'de> for SkillSuggestionSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SkillSuggestionSettings
impl JsonSchema for SkillSuggestionSettings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SkillSuggestionSettings
impl PartialEq for SkillSuggestionSettings
Sourceimpl Serialize for SkillSuggestionSettings
impl Serialize for SkillSuggestionSettings
impl StructuralPartialEq for SkillSuggestionSettings