pub struct TtsrRuleSetting {
pub pattern: String,
pub reminder: String,
}Fields
pattern: Stringreminder: StringTrait Implementations
Sourceimpl Clone for TtsrRuleSetting
impl Clone for TtsrRuleSetting
Sourcefn clone(&self) -> TtsrRuleSetting
fn clone(&self) -> TtsrRuleSetting
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TtsrRuleSetting
impl Debug for TtsrRuleSetting
Sourceimpl Default for TtsrRuleSetting
impl Default for TtsrRuleSetting
Sourcefn default() -> TtsrRuleSetting
fn default() -> TtsrRuleSetting
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TtsrRuleSetting
impl<'de> Deserialize<'de> for TtsrRuleSetting
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TtsrRuleSetting
Sourceimpl JsonSchema for TtsrRuleSetting
impl JsonSchema for TtsrRuleSetting
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TtsrRuleSetting
impl PartialEq for TtsrRuleSetting
Sourceimpl Serialize for TtsrRuleSetting
impl Serialize for TtsrRuleSetting
impl StructuralPartialEq for TtsrRuleSetting