pub struct SideAgentSettings {
pub provider: Option<String>,
pub model: Option<String>,
}Fields
provider: Option<String>model: Option<String>Trait Implementations
Sourceimpl Clone for SideAgentSettings
impl Clone for SideAgentSettings
Sourcefn clone(&self) -> SideAgentSettings
fn clone(&self) -> SideAgentSettings
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SideAgentSettings
impl Debug for SideAgentSettings
Sourceimpl Default for SideAgentSettings
impl Default for SideAgentSettings
Sourcefn default() -> SideAgentSettings
fn default() -> SideAgentSettings
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SideAgentSettings
impl<'de> Deserialize<'de> for SideAgentSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SideAgentSettings
Sourceimpl JsonSchema for SideAgentSettings
impl JsonSchema for SideAgentSettings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SideAgentSettings
impl PartialEq for SideAgentSettings
Sourceimpl Serialize for SideAgentSettings
impl Serialize for SideAgentSettings
impl StructuralPartialEq for SideAgentSettings